library(phyloseq)
library(ape)
library(tidyverse)
library(picante)
library(ggsignif)
library(ggplot2)
library(microbiome)
library(ggVennDiagram)


######################################Alpha Diversity Metrics##########################################


#### Load in RData ####

load("fish_phyloseq.RData")
#----------------------------------


####filtering####

# Remove non-bacterial sequences
fish_filt <- subset_taxa(fish,  Domain == "d__Bacteria" & Class!="c__Chloroplast" & Family !="f__Mitochondria")

save(fish_filt, file = "fish_filt.Rdata")
#----------------------------------


####rarefaction####
load("fish_phyloseq_rare.RData")
#fish_rare <- rarefy_even_depth(fish_filt, rngseed = 1, sample.size = 1704)
#Don't run again, avoid different rarefaction if environment is cleared
#----------------------------------


####Preparation for stats

#alpha diversity measures for all samples
alphadiv <- estimate_richness(fish_rare)

#extract metadata from the rarefied phyloseq
meta <- sample_data(fish_rare)

#append all alpha diversity measures into the metadata
meta_wdiv <- data.frame(meta, alphadiv)

# calculate Faith's phylogenetic diversity as PD
phylo_dist <- pd(t(otu_table(fish_rare)), phy_tree(fish_rare),
                 include.root=F) 

# add PD to metadata table
meta_wdiv$PD <- phylo_dist$PD
#----------------------------------


####Kruskall-Wallis for general groups (Shannon, Chao1)
kruskal_gen_Shannon <- kruskal.test(Shannon ~ `gen_grouping`, data = meta_wdiv)
kruskal_gen_Shannon

kruskal_gen_Chao1 <- kruskal.test(Chao1 ~ `gen_grouping`, data = meta_wdiv)
kruskal_gen_Chao1
#----------------------------------


####plot_richness for gen_grouping####

gg_richness <- plot_richness(fish_rare, x = "gen_grouping", measures = c("Shannon","Chao1")) +
  xlab("General Diet Group") +
  geom_boxplot() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1, vjust = 1.1)) +
  geom_point()
gg_richness

#save
ggsave(filename = "Shannon&Chao1_gen_group.png"
       , gg_richness
       , height=6, width=10)
#save as final output
ggsave(filename = "../Final_Plots_and_Tables/Shannon&Chao1_gen_group.png"
       , gg_richness
       , height=6, width=10)
#----------------------------------


####alpha diversity plot for 11 diet groups####


####Crustacean vs Other---------------------------------------------------------

#Wilcoxon for shannon, Crustacean
wilcox_Crustacean_Shannon <- wilcox.test(Shannon ~ `Crustacean`, data = meta_wdiv, exact = FALSE)
wilcox_Crustacean_Shannon

#Shannon plot
shannon_Crustacean <- plot_richness(fish_rare, x = "Crustacean", measures = c("Shannon")) +
  xlab("Crustacean") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.1313"))
shannon_Crustacean

ggsave(filename = "./Shannon&PD_specific_group/shannon_Crustacean.png"
       , shannon_Crustacean
       , height=5, width=6)

#Wilcoxon for PD, Crustacean
wilcox_Crustacean_PD <- wilcox.test(PD ~ `Crustacean`, data = meta_wdiv, exact = FALSE)
wilcox_Crustacean_PD

#faith's PD plot
PD_Crustacean <- ggplot(meta_wdiv, aes(Crustacean, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Crustacean") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.08134"))
PD_Crustacean

ggsave(filename = "./Shannon&PD_specific_group/PD_Crustacean.png"
       , PD_Crustacean
       , height=5, width=6)


####Worm vs Other---------------------------------------------------------------

#Wilcoxon for shannon, Worm
wilcox_Worm_Shannon <- wilcox.test(Shannon ~ `Worm`, data = meta_wdiv, exact = FALSE)
wilcox_Worm_Shannon

#Shannon plot
shannon_Worm <- plot_richness(fish_rare, x = "Worm", measures = c("Shannon")) +
  xlab("Worm") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.9213"))
shannon_Worm

ggsave(filename = "./Shannon&PD_specific_group/shannon_Worm.png"
       , shannon_Worm
       , height=5, width=6)

#Wilcoxon for PD, Worm
wilcox_Worm_PD <- wilcox.test(PD ~ `Worm`, data = meta_wdiv, exact = FALSE)
wilcox_Worm_PD

#faith's PD plot
PD_Worm <- ggplot(meta_wdiv, aes(Worm, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Worm") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.4537"))
PD_Worm

ggsave(filename = "./Shannon&PD_specific_group/PD_Worm.png"
       , PD_Worm
       , height=5, width=6)


####Mollusk vs Other------------------------------------------------------------

#Wilcoxon for shannon, Mollusk
wilcox_Mollusk_Shannon <- wilcox.test(Shannon ~ `Mollusk`, data = meta_wdiv, exact = FALSE)
wilcox_Mollusk_Shannon

#Shannon plot
shannon_Mollusk <- plot_richness(fish_rare, x = "Mollusk", measures = c("Shannon")) +
  xlab("Mollusk") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.06617"))
shannon_Mollusk

ggsave(filename = "./Shannon&PD_specific_group/shannon_Mollusk.png"
       , shannon_Mollusk
       , height=5, width=6)

#Wilcoxon for PD, Mollusk
wilcox_Mollusk_PD <- wilcox.test(PD ~ `Mollusk`, data = meta_wdiv, exact = FALSE)
wilcox_Mollusk_PD

#faith's PD plot
PD_Mollusk <- ggplot(meta_wdiv, aes(Mollusk, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Mollusk") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.07888"))
PD_Mollusk

ggsave(filename = "./Shannon&PD_specific_group/PD_Mollusk.png"
       , PD_Mollusk
       , height=5, width=6)


####Fish vs Other---------------------------------------------------------------

#Wilcoxon for shannon, Fish
wilcox_Fish_Shannon <- wilcox.test(Shannon ~ `Fish`, data = meta_wdiv, exact = FALSE)
wilcox_Fish_Shannon

#Shannon plot
shannon_Fish <- plot_richness(fish_rare, x = "Fish", measures = c("Shannon")) +
  xlab("Fish") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.329"))
shannon_Fish

ggsave(filename = "./Shannon&PD_specific_group/shannon_Fish.png"
       , shannon_Fish
       , height=5, width=6)

#Wilcoxon for PD, Fish
wilcox_Fish_PD <- wilcox.test(PD ~ `Fish`, data = meta_wdiv, exact = FALSE)
wilcox_Fish_PD

#faith's PD plot
PD_Fish <- ggplot(meta_wdiv, aes(Fish, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Fish") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.3204"))
PD_Fish

ggsave(filename = "./Shannon&PD_specific_group/PD_Fish.png"
       , PD_Fish
       , height=5, width=6)

####Zooplankton vs Other--------------------------------------------------------

#Wilcoxon for shannon, Zooplankton
wilcox_Zooplankton_Shannon <- wilcox.test(Shannon ~ `Zooplankton`, data = meta_wdiv, exact = FALSE)
wilcox_Zooplankton_Shannon

#Shannon plot
shannon_Zooplankton <- plot_richness(fish_rare, x = "Zooplankton", measures = c("Shannon")) +
  xlab("Zooplankton") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.3078"))
shannon_Zooplankton

ggsave(filename = "./Shannon&PD_specific_group/shannon_Zooplankton.png"
       , shannon_Zooplankton
       , height=5, width=6)

#Wilcoxon for PD, Zooplankton
wilcox_Zooplankton_PD <- wilcox.test(PD ~ `Zooplankton`, data = meta_wdiv, exact = FALSE)
wilcox_Zooplankton_PD

#faith's PD plot
PD_Zooplankton <- ggplot(meta_wdiv, aes(Zooplankton, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Zooplankton") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.8915"))
PD_Zooplankton

ggsave(filename = "./Shannon&PD_specific_group/PD_Zooplankton.png"
       , PD_Zooplankton
       , height=5, width=6)


####Omnivores vs Other----------------------------------------------------------

#Wilcoxon for shannon, Omnivores
wilcox_Omnivores_Shannon <- wilcox.test(Shannon ~ `Omnivores`, data = meta_wdiv, exact = FALSE)
wilcox_Omnivores_Shannon

#Shannon plot
shannon_Omnivores <- plot_richness(fish_rare, x = "Omnivores", measures = c("Shannon")) +
  xlab("Omnivores") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.9921"))
shannon_Omnivores

ggsave(filename = "./Shannon&PD_specific_group/shannon_Omnivores.png"
       , shannon_Omnivores
       , height=5, width=6)

#Wilcoxon for PD, Omnivores
wilcox_Omnivores_PD <- wilcox.test(PD ~ `Omnivores`, data = meta_wdiv, exact = FALSE)
wilcox_Omnivores_PD

#faith's PD plot
PD_Omnivores <- ggplot(meta_wdiv, aes(Omnivores, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Omnivores") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.1298"))
PD_Omnivores

ggsave(filename = "./Shannon&PD_specific_group/PD_Omnivores.png"
       , PD_Omnivores
       , height=5, width=6)


####Herbivores vs Other---------------------------------------------------------

#Wilcoxon for shannon, Herbivores
wilcox_Herbivores_Shannon <- wilcox.test(Shannon ~ `Herbivores`, data = meta_wdiv, exact = FALSE)
wilcox_Herbivores_Shannon

#Shannon plot
shannon_Herbivores <- plot_richness(fish_rare, x = "Herbivores", measures = c("Shannon")) +
  xlab("Herbivores") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.7713"))
shannon_Herbivores

ggsave(filename = "./Shannon&PD_specific_group/shannon_Herbivores.png"
       , shannon_Herbivores
       , height=5, width=6)

#Wilcoxon for PD, Herbivores
wilcox_Herbivores_PD <- wilcox.test(PD ~ `Herbivores`, data = meta_wdiv, exact = FALSE)
wilcox_Herbivores_PD

#faith's PD plot
PD_Herbivores <- ggplot(meta_wdiv, aes(Herbivores, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Herbivores") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.3537"))
PD_Herbivores

ggsave(filename = "./Shannon&PD_specific_group/PD_Herbivores.png"
       , PD_Herbivores
       , height=5, width=6)


####Pure.Crustacean.feeders vs Other--------------------------------------------

#Wilcoxon for shannon, Pure.Crustacean.feeders
wilcox_PureCrust_Shannon <- wilcox.test(Shannon ~ `Pure.Crustacean.feeders`, data = meta_wdiv, exact = FALSE)
wilcox_PureCrust_Shannon

#Shannon plot
shannon_PureCrust <- plot_richness(fish_rare, x = "Pure.Crustacean.feeders", measures = c("Shannon")) +
  xlab("Pure.Crustacean.feeders") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.5371"))
shannon_PureCrust

ggsave(filename = "./Shannon&PD_specific_group/shannon_PureCrust.png"
       , shannon_PureCrust
       , height=5, width=6)

#Wilcoxon for PD, Pure.Crustacean.feeders
wilcox_PureCrust_PD <- wilcox.test(PD ~ `Pure.Crustacean.feeders`, data = meta_wdiv, exact = FALSE)
wilcox_PureCrust_PD

#faith's PD plot
PD_PureCrust <- ggplot(meta_wdiv, aes(Pure.Crustacean.feeders, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Pure.Crustacean.feeders") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.7547"))
PD_PureCrust

ggsave(filename = "./Shannon&PD_specific_group/PD_PureCrust.png"
       , PD_PureCrust
       , height=5, width=6)


####Pure.Piscivore vs Other-----------------------------------------------------

#Wilcoxon for shannon, Pure.Piscivore
wilcox_PurePisc_Shannon <- wilcox.test(Shannon ~ `Pure.Piscivore`, data = meta_wdiv, exact = FALSE)
wilcox_PurePisc_Shannon

#Shannon plot
shannon_PurePisc <- plot_richness(fish_rare, x = "Pure.Piscivore", measures = c("Shannon")) +
  xlab("Pure.Piscivore") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.4766"))
shannon_PurePisc

ggsave(filename = "./Shannon&PD_specific_group/shannon_PurePisc.png"
       , shannon_PurePisc
       , height=5, width=6)

#Wilcoxon for PD, Pure.Piscivore
wilcox_PurePisc_PD <- wilcox.test(PD ~ `Pure.Piscivore`, data = meta_wdiv, exact = FALSE)
wilcox_PurePisc_PD

#faith's PD plot
PD_PurePisc <- ggplot(meta_wdiv, aes(Pure.Piscivore, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Pure.Piscivore") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.6063"))
PD_PurePisc

ggsave(filename = "./Shannon&PD_specific_group/PD_PurePisc.png"
       , PD_PurePisc
       , height=5, width=6)


####Mixed.Carnivores.low.trophic.level vs Other---------------------------------

#Wilcoxon for shannon, Mixed.Carnivores.low.trophic.level
wilcox_MixLow_Shannon <- wilcox.test(Shannon ~ `Mixed.Carnivores.low.trophic.level`, data = meta_wdiv, exact = FALSE)
wilcox_MixLow_Shannon

#Shannon plot
shannon_MixLow <- plot_richness(fish_rare, x = "Mixed.Carnivores.low.trophic.level", measures = c("Shannon")) +
  xlab("Specific Diet Group") +
  scale_x_discrete(labels = c("Other","Mixed Carnivores-Low Trophic Level")) +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 0.5)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.0033 *"))
shannon_MixLow

ggsave(filename = "./Shannon&PD_specific_group/shannon_MixLow.png"
       , shannon_MixLow
       , height=5, width=6)
#save as final output
ggsave(filename = "../Final_Plots_and_Tables/shannon_MixLow.png"
       , shannon_MixLow
       , height=5, width=6)

#Wilcoxon for PD, Mixed.Carnivores.low.trophic.level
wilcox_MixLow_PD <- wilcox.test(PD ~ `Mixed.Carnivores.low.trophic.level`, data = meta_wdiv, exact = FALSE)
wilcox_MixLow_PD

#faith's PD plot
PD_MixLow <- ggplot(meta_wdiv, aes(Mixed.Carnivores.low.trophic.level, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Specific Diet Group") +
  scale_x_discrete(labels = c("Other","Mixed Carnivores-Low Trophic Level")) +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.0028 *"))
PD_MixLow

ggsave(filename = "./Shannon&PD_specific_group/PD_MixLow.png"
       , PD_MixLow
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/PD_MixLow.png"
       , PD_MixLow
       , height=5, width=6)

####Mixed.Carnivores.high.trophic.level vs Other--------------------------------

#Wilcoxon for shannon, Mixed.Carnivores.high.trophic.level
wilcox_MixHigh_Shannon <- wilcox.test(Shannon ~ `Mixed.Carnivores.high.trophic.level`, data = meta_wdiv, exact = FALSE)
wilcox_MixHigh_Shannon

#Shannon plot
shannon_MixHigh <- plot_richness(fish_rare, x = "Mixed.Carnivores.high.trophic.level", measures = c("Shannon")) +
  xlab("Mixed.Carnivores.high.trophic.level") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 1)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.1314"))
shannon_MixHigh

ggsave(filename = "./Shannon&PD_specific_group/shannon_MixHigh.png"
       , shannon_MixHigh
       , height=5, width=6)

#Wilcoxon for PD, Mixed.Carnivores.high.trophic.level
wilcox_MixHigh_PD <- wilcox.test(PD ~ `Mixed.Carnivores.high.trophic.level`, data = meta_wdiv, exact = FALSE)
wilcox_MixHigh_PD

#faith's PD plot
PD_MixHigh <- ggplot(meta_wdiv, aes(Mixed.Carnivores.high.trophic.level, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Mixed.Carnivores.high.trophic.level") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.4302"))
PD_MixHigh

ggsave(filename = "./Shannon&PD_specific_group/PD_MixHigh.png"
       , PD_MixHigh
       , height=5, width=6)


###############Check if location is a driving force for alpha diversity####################


#Wilcoxon for shannon, location
wilcox_loc_Shannon <- wilcox.test(Shannon ~ `sample_type`, data = meta_wdiv, exact = FALSE)
wilcox_loc_Shannon

#Shannon plot
shannon_loc <- plot_richness(fish_rare, x = "sample_type", measures = c("Shannon")) +
  xlab("Sample Location") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 0.5)) +
  geom_signif(comparisons = list(c("hindgut","midgut")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value << 0.05 *"))
shannon_loc

ggsave(filename = "./Location_Alpha_diversity/shannon_loc.png"
       , shannon_loc
       , height=5, width=6)
#save as final output
ggsave(filename = "../Final_Plots_and_Tables/shannon_loc.png"
       , shannon_loc
       , height=5, width=6)

#Wilcoxon for Chao1, location
wilcox_loc_Chao1 <- wilcox.test(Chao1 ~ `sample_type`, data = meta_wdiv, exact = FALSE)
wilcox_loc_Chao1

#Chao1 plot
Chao1_loc <- plot_richness(fish_rare, x = "sample_type", measures = c("Chao1")) +
  xlab("Sample Location") +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 0.5)) +
  geom_signif(comparisons = list(c("hindgut","midgut")),
              y_position = c(210),
              annotations = c("Wilcoxon, p-value << 0.05 *"))
Chao1_loc

ggsave(filename = "./Location_Alpha_diversity/Chao1_loc.png"
       , Chao1_loc
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/Chao1_loc.png"
       , Chao1_loc
       , height=5, width=6)


#Wilcoxon for PD, location
wilcox_loc_PD <- wilcox.test(PD ~ `sample_type`, data = meta_wdiv, exact = FALSE)
wilcox_loc_PD

#faith's PD plot
PD_loc <- ggplot(meta_wdiv, aes(sample_type, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Sample Location") +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("hindgut","midgut")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value << 0.05 *"))
PD_loc

ggsave(filename = "./Location_Alpha_diversity/PD_loc.png"
       , PD_loc
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/PD_loc.png"
       , PD_loc
       , height=5, width=6)


#################Check if trophic level is a key palyer in alpha diversity#############################


####Trophic Level####-----------------------------------------------------------

####Kruskall-Wallis for Trophic Level (Shannon, Chao1)
kruskal_trophic_Shannon <- kruskal.test(Shannon ~ `trophic`, data = meta_wdiv)
kruskal_trophic_Shannon
#0.5195

kruskal_trophic_Chao1 <- kruskal.test(Chao1 ~ `trophic`, data = meta_wdiv)
kruskal_trophic_Chao1
#0.8682

kruskal_trophic_PD <- kruskal.test(PD ~ `trophic`, data = meta_wdiv)
kruskal_trophic_PD
#0.7371


############Regenerating alpha diversity metrics for LTLMC group in Hindgut and Midgut separately#############


load("fish_phyloseq_rare.RData")
fish_rare_meta <- sample_data(fish_rare)


#######Midgut-------------------------------------------------------------------
Midgut_rare <- subset_samples(fish_rare, sample_type == "midgut")

Midgut_rare_meta <- sample_data(Midgut_rare)

save(Midgut_rare, file = "Midgut_rare.Rdata")

#######Hindgut------------------------------------------------------------------
Hindgut_rare <- subset_samples(fish_rare, sample_type == "hindgut")

Hindgut_rare_meta <- sample_data(Hindgut_rare)

save(Hindgut_rare, file = "Hindgut_rare.Rdata")


####Preparation for stats-------------------------------------------------------

####Midgut----------------------------------------------------------------------

#generate alpha diversity for midgut samples
Midgut_alphadiv <- estimate_richness(Midgut_rare)

#Append alpha diversity into metadata
Midgut_meta_wdiv <- data.frame(Midgut_rare_meta, Midgut_alphadiv)

# calculate Faith's phylogenetic diversity as PD
Midgut_pd <- pd(t(otu_table(Midgut_rare)), phy_tree(Midgut_rare),
                include.root=F)

# add PD to metadata table
Midgut_meta_wdiv$PD <- Midgut_pd$PD


####Hindgut---------------------------------------------------------------------

#generate alpha diversity for midgut samples
Hindgut_alphadiv <- estimate_richness(Hindgut_rare)

#Append alpha diversity into metadata
Hindgut_meta_wdiv <- data.frame(Hindgut_rare_meta, Hindgut_alphadiv)

# calculate Faith's phylogenetic diversity as PD
Hindgut_pd <- pd(t(otu_table(Hindgut_rare)), phy_tree(Hindgut_rare),
                 include.root=F)

# add PD to metadata table
Hindgut_meta_wdiv$PD <- Hindgut_pd$PD


####Kruskall-Wallis for general groups (Shannon, Chao1)-------------------------

####Midgut
kruskal_gen_Shannon_mid <- kruskal.test(Shannon ~ `gen_grouping`, data = Midgut_meta_wdiv)
kruskal_gen_Shannon_mid
#0.6931

kruskal_gen_Chao1_mid <- kruskal.test(Chao1 ~ `gen_grouping`, data = Midgut_meta_wdiv)
kruskal_gen_Chao1_mid
#0.4279

####Hindgut
kruskal_gen_Shannon_hind <- kruskal.test(Shannon ~ `gen_grouping`, data = Hindgut_meta_wdiv)
kruskal_gen_Shannon_hind
#0.2667

kruskal_gen_Chao1_hind <- kruskal.test(Chao1 ~ `gen_grouping`, data = Hindgut_meta_wdiv)
kruskal_gen_Chao1_hind
#0.3236


#####alpha diversity plot for Mixed carnivores low trophic level in Hind/Midgut

####Midgut----------------------------------------------------------------------

#Wilcoxon for shannon, Mixed.Carnivores.low.trophic.level
Midgut_wilcox_MixLow_Shannon <- wilcox.test(Shannon ~ `Mixed.Carnivores.low.trophic.level`, data = Midgut_meta_wdiv, exact = FALSE)
Midgut_wilcox_MixLow_Shannon
#0.001508

#Shannon plot
Midgut_shannon_MixLow <- plot_richness(Midgut_rare, x = "Mixed.Carnivores.low.trophic.level", measures = c("Shannon")) +
  xlab("Specific Diet Group") +
  scale_x_discrete(labels = c("Other","Mixed Carnivores-Low Trophic Level")) +
  geom_boxplot() +
  geom_point() +
  theme(axis.text.x = element_text(angle = 360, hjust = 0.5)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.0015 *"))
Midgut_shannon_MixLow

ggsave(filename = "./Shannon&PD_MixLow/Midgut_shannon_MixLow.png"
       , Midgut_shannon_MixLow
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/Midgut_shannon_MixLow.png"
       , Midgut_shannon_MixLow
       , height=5, width=6)

#Wilcoxon for PD, Mixed.Carnivores.low.trophic.level
Midgut_wilcox_MixLow_PD <- wilcox.test(PD ~ `Mixed.Carnivores.low.trophic.level`, data = Midgut_meta_wdiv, exact = FALSE)
Midgut_wilcox_MixLow_PD
#0.002295

#faith's PD plot
Midgut_PD_MixLow <- ggplot(Midgut_meta_wdiv, aes(Mixed.Carnivores.low.trophic.level, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Specific Diet Group") +
  scale_x_discrete(labels = c("Other","Mixed Carnivores-Low Trophic Level")) +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(20),
              annotations = c("Wilcoxon, p-value = 0.0023 *"))
Midgut_PD_MixLow

ggsave(filename = "./Shannon&PD_MixLow/Midgut_PD_MixLow.png"
       , Midgut_PD_MixLow
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/Midgut_PD_MixLow.png"
       , Midgut_PD_MixLow
       , height=5, width=6)
####Hindgut---------------------------------------------------------------------

#Wilcoxon for shannon, Mixed.Carnivores.low.trophic.level
Hindgut_wilcox_MixLow_Shannon <- wilcox.test(Shannon ~ `Mixed.Carnivores.low.trophic.level`, data = Hindgut_meta_wdiv, exact = FALSE)
Hindgut_wilcox_MixLow_Shannon
#0.5981

#Shannon plot
Hindgut_shannon_MixLow <- plot_richness(Hindgut_rare, x = "Mixed.Carnivores.low.trophic.level", measures = c("Shannon")) +
  geom_boxplot() +
  geom_point() +
  xlab("Specific Diet Group") +
  scale_x_discrete(labels = c("Other","Mixed Carnivores-Low Trophic Level")) +
  theme(axis.text.x = element_text(angle = 360, hjust = 0.5)) +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(5),
              annotations = c("Wilcoxon, p-value = 0.5981"))
Hindgut_shannon_MixLow

ggsave(filename = "./Shannon&PD_MixLow/Hindgut_shannon_MixLow.png"
       , Hindgut_shannon_MixLow
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/Hindgut_shannon_MixLow.png"
       , Hindgut_shannon_MixLow
       , height=5, width=6)

#Wilcoxon for PD, Mixed.Carnivores.low.trophic.level
Hindgut_wilcox_MixLow_PD <- wilcox.test(PD ~ `Mixed.Carnivores.low.trophic.level`, data = Hindgut_meta_wdiv, exact = FALSE)
Hindgut_wilcox_MixLow_PD
#0.5981

#faith's PD plot
Hindgut_PD_MixLow <- ggplot(Hindgut_meta_wdiv, aes(Mixed.Carnivores.low.trophic.level, PD)) + 
  geom_boxplot() +
  geom_point() +
  xlab("Specific Diet Group") +
  scale_x_discrete(labels = c("Other","Mixed Carnivores-Low Trophic Level")) +
  ylab("Phylogenetic Diversity") +
  geom_signif(comparisons = list(c("0","1")),
              y_position = c(12.6),
              annotations = c("Wilcoxon, p-value = 0.5981"))
Hindgut_PD_MixLow

ggsave(filename = "./Shannon&PD_MixLow/Hindgut_PD_MixLow.png"
       , Hindgut_PD_MixLow
       , height=5, width=6)

ggsave(filename = "../Final_Plots_and_Tables/Hindgut_PD_MixLow.png"
       , Hindgut_PD_MixLow
       , height=5, width=6)


#######Plotting alpha diversity for LTLMC group using original diet column of the initial metadata in Hind/Midgut


#####Filter for ONLY mixed low carnivores group

#####Midgut
Midgut_meta_wdiv_MixLow <- filter(Midgut_meta_wdiv, Mixed.Carnivores.low.trophic.level == "1") 

#####Hindgut
Hindgut_meta_wdiv_MixLow <- filter(Hindgut_meta_wdiv, Mixed.Carnivores.low.trophic.level == "1")


###########Generate alpha diversity measure of the original diet grouping of mixed low carnivores group#############


#####Midgut---------------------------------------------------------------------

##Shannon
Midgut_MixLow_Shannon_original_diet <- ggplot(Midgut_meta_wdiv_MixLow, aes(Diet, Shannon)) +
  geom_boxplot() +
  geom_point() +
  xlab("Original Diet Group") +
  theme(axis.text.x = element_text(angle = 70, hjust = 1, size = 8)) +                                
  ylab("Shannon") +
  ggtitle("Midgut")
Midgut_MixLow_Shannon_original_diet

ggsave(filename = "./Alphadiv_Original_diet_MixLow/Midgut_MixLow_Shannon_original_diet.png"
       , Midgut_MixLow_Shannon_original_diet
       , height=12, width=10)

##Chao1
Midgut_MixLow_Chao1_original_diet <- ggplot(Midgut_meta_wdiv_MixLow, aes(Diet, Chao1)) +
  geom_boxplot() +
  geom_point() +
  xlab("Original Diet Group") +
  theme(axis.text.x = element_text(angle = 70, hjust = 1, size = 8)) +
  ylab("Chao1") +
  ggtitle("Midgut")
Midgut_MixLow_Chao1_original_diet

ggsave(filename = "./Alphadiv_Original_diet_MixLow/Midgut_MixLow_Chao1_original_diet.png"
       , Midgut_MixLow_Chao1_original_diet
       , height=12, width=10)

##PD
Midgut_MixLow_PD_original_diet <- ggplot(Midgut_meta_wdiv_MixLow, aes(Diet, PD)) +
  geom_boxplot() +
  geom_point() +
  xlab("Original Diet Group") +
  theme(axis.text.x = element_text(angle = 70, hjust = 1, size = 8)) +                              
  ylab("PD") +
  ggtitle("Midgut")
Midgut_MixLow_PD_original_diet

ggsave(filename = "./Alphadiv_Original_diet_MixLow/Midgut_MixLow_PD_original_diet.png"
       , Midgut_MixLow_PD_original_diet
       , height=12, width=10)

#####Hindgut--------------------------------------------------------------------

##Shannon
Hindgut_MixLow_Shannon_original_diet <- ggplot(Hindgut_meta_wdiv_MixLow, aes(Diet, Shannon)) +
  geom_boxplot() +
  geom_point() +
  xlab("Original Diet Group") +
  theme(axis.text.x = element_text(angle = 70, hjust = 1, size = 8)) +                                
  ylab("Shannon") +
  ggtitle("Hindgut")
Hindgut_MixLow_Shannon_original_diet

ggsave(filename = "./Alphadiv_Original_diet_MixLow/Hindgut_MixLow_Shannon_original_diet.png"
       , Hindgut_MixLow_Shannon_original_diet
       , height=12, width=10)

##Chao1
Hindgut_MixLow_Chao1_original_diet <- ggplot(Hindgut_meta_wdiv_MixLow, aes(Diet, Chao1)) +
  geom_boxplot() +
  geom_point() +
  xlab("Original Diet Group") +
  theme(axis.text.x = element_text(angle = 70, hjust = 1, size = 8)) +                                
  ylab("Chao1") +
  ggtitle("Hindgut")
Hindgut_MixLow_Chao1_original_diet

ggsave(filename = "./Alphadiv_Original_diet_MixLow/Hindgut_MixLow_Chao1_original_diet.png"
       , Hindgut_MixLow_Chao1_original_diet
       , height=12, width=10)

##PD
Hindgut_MixLow_PD_original_diet <- ggplot(Hindgut_meta_wdiv_MixLow, aes(Diet, PD)) +
  geom_boxplot() +
  geom_point() +
  xlab("Original Diet Group") +
  theme(axis.text.x = element_text(angle = 70, hjust = 1, size = 8)) +                                
  ylab("PD") +
  ggtitle("Hindgut")
Hindgut_MixLow_PD_original_diet

ggsave(filename = "./Alphadiv_Original_diet_MixLow/Hindgut_MixLow_PD_original_diet.png"
       , Hindgut_MixLow_PD_original_diet
       , height=12, width=10)


######################################Core Microbiome Analysis##########################################


#load the UNRAREFIED, filtered phyloseq
load("../Alpha_diversity/fish_filt.Rdata")

# Convert to relative abundance
fish_filt_unrare_RA <- transform_sample_counts(fish_filt, fun=function(x) x/sum(x))

#focus only on midgut samples
Midgut_filt_unrare_RA <- subset_samples(fish_filt_unrare_RA, sample_type == "midgut")

Midgut_filt_unrare_RA_meta <- sample_data(Midgut_filt_unrare_RA)

# Subset dataset by mixed low group (yes or no)
Mixed_low_yes <- subset_samples(Midgut_filt_unrare_RA, `Mixed.Carnivores.low.trophic.level`=="1")
Mixed_low_no <- subset_samples(Midgut_filt_unrare_RA, `Mixed.Carnivores.low.trophic.level`=="0")

# Set a prevalence threshold and abundance threshold
Mixed_low_yes_ASVs <- core_members(Mixed_low_yes, detection=0.001, prevalence = 0)
Mixed_low_no_ASVs <- core_members(Mixed_low_no, detection=0.001, prevalence = 0)

#Making a Venn Diagram
Core_midgut_mixlow <- ggVennDiagram(
  x=list(Mixed_low_yes_ASVs, Mixed_low_no_ASVs),
  label_alpha = 0,
  category.names = c("Mixed Carnivores\nLow Trophic Levels", "Other"),
  label_color = "black") +
  scale_color_brewer(palette = "Set2") +
  labs(title = "Core Microbiome Analysis in Midgut Samples") +
  scale_fill_gradient(low="skyblue",high = "pink") +
  theme(plot.title = element_text(hjust = 0.5, vjust = 4))
Core_midgut_mixlow

ggsave("./Core_Microbiome/Core_midgut_mixlow.png", Core_midgut_mixlow, height=6, width=7)
#save as final output
ggsave("../Final_Plots_and_Tables/Core_midgut_mixlow.png", Core_midgut_mixlow, height=6, width=7)


#############A higher Prevalence Value lead to significant loss of ASVs##########


# Try a higher prevalence value
Mixed_low_yes_ASVs2 <- core_members(Mixed_low_yes, detection=0.001, prevalence = 0.3)
Mixed_low_no_ASVs2 <- core_members(Mixed_low_no, detection=0.001, prevalence = 0.3)

#Making a Venn Diagram
Core_midgut_mixlow2 <- ggVennDiagram(
  x=list(Mixed_low_yes_ASVs2, Mixed_low_no_ASVs2),
  label_alpha = 0,
  category.names = c("Mixed Carnivores\nLow Trophic Levels", "Other"),
  label_color = "black") +
  scale_color_brewer(palette = "Set2") +
  labs(title = "Core Microbiome Analysis in Midgut Samples",
       caption = "Prevalence = 0.3") +
  scale_fill_gradient(low="skyblue",high = "pink") +
  theme(plot.title = element_text(hjust = 0.5, vjust = 4))
Core_midgut_mixlow2

#ggsave("./Core_Microbiome/Core_midgut_mixlow2.png", Core_midgut_mixlow2, height=6, width=7)
#save as final output
#ggsave("../Final_Plots_and_Tables/Core_midgut_mixlow2.png", Core_midgut_mixlow2, height=6, width=7)