#!/usr/bin/env RScript

#load packages
library(readr)
library(ggpicrust2)
library(tibble)
library(tidyr)
library(tidyverse)
library(ggprism)
library(patchwork)
library(DESeq2)
source("DESeq2_function.R")
library("ggh4x")

#Import files
abundance_file <- "path_abun_unstrat.tsv"
abundance_data <-   as.data.frame(read_delim(abundance_file, delim = "\t", col_names = TRUE, trim_ws = TRUE))

metadata <- read_delim("meta.tsv")

#Filter your metadata as needed to look at specific comparisons 
meta = metadata %>%
  filter (sample_type=="midgut") %>%
  select(sampleID, Mixed_Carnivores_low_trophic_level) %>%
  mutate(Mixed_Carnivores_low_trophic_level = ifelse(Mixed_Carnivores_low_trophic_level == 1, "yes", "no"))

 
#Filtering the abundance table to only include samples that are in the filtered metadata
sample_names = meta$sampleID
sample_names = append(sample_names, "pathway")
abundance_data_filtered = abundance_data[, colnames(abundance_data) %in% sample_names] #This step is the actual filtering

#Removing individuals with no data that caused a problem for pathways_daa()
abundance_data_filtered =  abundance_data_filtered[, colSums(abundance_data_filtered != 0) > 0]

#Ensuring the rownames for the abundance_data_filtered is empty. This is required for their functions to run.
rownames(abundance_data_filtered) = NULL

#verify samples in metadata match samples in abundance_data
abun_samples = rownames(t(abundance_data_filtered[,-1])) 
meta = meta[meta$sampleID %in% abun_samples,] 


#Perform pathway DAA using DESEQ2 method
abundance_daa_results_df <- pathway_daa(abundance = abundance_data_filtered %>% column_to_rownames("pathway"), metadata = meta, group = "Mixed_Carnivores_low_trophic_level", daa_method = "DESeq2")

# Annotate MetaCyc pathway results without KO to KEGG conversion
metacyc_daa_annotated_results_df <- pathway_annotation(pathway = "MetaCyc", daa_results_df = abundance_daa_results_df, ko_to_kegg = FALSE)

# Generate pathway heatmap
feature_with_p_0.05 <- abundance_daa_results_df %>% filter(p_values < 0.01)

#Changing the pathway column to description for the results 
feature_desc = inner_join(feature_with_p_0.05,metacyc_daa_annotated_results_df, by = "feature")
feature_desc$feature = feature_desc$description
feature_desc = feature_desc[,c(1:7)]
colnames(feature_desc) = colnames(feature_with_p_0.05)

#Changing the pathway column to description for the abundance table
abundance = abundance_data_filtered %>% filter(pathway %in% feature_with_p_0.05$feature)
colnames(abundance)[1] = "feature"
abundance_desc = inner_join(abundance,metacyc_daa_annotated_results_df, by = "feature")
abundance_desc$feature = abundance_desc$description
abundance_desc = abundance_desc[,-c(98:ncol(abundance_desc))] #98 columns, 434 rows filtered abundance table

#plot on heatmap
plot <- pathway_heatmap(
  abundance = abundance_desc %>% column_to_rownames("feature"),
  metadata = meta,
  group = "Mixed_Carnivores_low_trophic_level")
ggsave("pathway_heatmap_plot.png", plot)

#Generate pathway PCA plot 
abundance_data <- abundance_data_filtered %>% column_to_rownames("pathway")
abundance_data_no_zeros <- abundance_data[rowSums(abundance_data != 0, na.rm = TRUE) > 0, ] # Remove rows with all zeros
pathway_pca_result <- pathway_pca(abundance = abundance_data_no_zeros, metadata = meta, group = "Mixed_Carnivores_low_trophic_level")
ggsave("pathway_pca_result_plot.png", pathway_pca_result)


#generating a bar plot representing log2FC from the custom deseq2 function
res =  DEseq2_function(abundance_data_filtered,meta,"Mixed_Carnivores_low_trophic_level")

res$feature =rownames(res)
res_desc = inner_join(res,metacyc_daa_annotated_results_df, by = "feature")
res_desc = res_desc[, -c(8:13)]
View(res_desc)

sig_res = res_desc %>%
  filter(pvalue < 0.05)

sig_res <- sig_res[order(sig_res$log2FoldChange),]
sig_res_plot <- ggplot(data = sig_res, aes(y = reorder(description, sort(as.numeric(log2FoldChange))), x= log2FoldChange, fill = pvalue))+
  geom_bar(stat = "identity")+ 
  theme_bw()+
  labs(x = "Log2FoldChange", y="Pathways")
ggsave("sig_res_plot.png", sig_res_plot)

